pub struct RTLDDebug {
pub r_brk: extern "C" fn(),
pub state: RTLDState,
pub r_ldbase: usize,
/* private fields */
}Expand description
Data structure for sharing debugging information from the run-time dynamic linker for loaded ELF shared objects.
Fields
r_brk: extern "C" fn()This is the address of a function internal to the run-time linker, that will always be called when the linker begins to map in a library or unmap it, and again when the mapping change is complete. The debugger can set a breakpoint at this address if it wants to notice shared object mapping changes.
state: RTLDStateThis state value describes the mapping change taking place when the `r_brk’ address is called.
r_ldbase: usizeBase address the linker is loaded at.
Implementations